/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * xgehrd.h
 *
 * Code generation for function 'xgehrd'
 *
 */

#ifndef XGEHRD_H
#define XGEHRD_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern void xgehrd(emxArray_real_T *a, emxArray_real_T *tau);

#endif

/* End of code generation (xgehrd.h) */
